tonik_core library

Core data structures and utilities for Tonik.

Classes

AliasModel
AllOfModel
AllOfNormalizer
Normalizes AllOfModel instances with a single contained model to AliasModel.
AnyModel
AnyOfModel
ApiDocument
ApiKeySecurityScheme
BinaryModel
BooleanModel
ClassModel
ConfigTransformer
Contact
ContentTypeNormalizer
Normalizes models based on HTTP content type.
Context
CookieParameter
CookieParameterAlias
CookieParameterObject
DateModel
DateTimeModel
DecimalModel
DefaultResponseStatus
DeprecatedConfig
Configuration for handling deprecated operations, schemas, parameters, and properties.
DoubleModel
EnumConfig
Configuration for enum generation.
EnumEntry<T>
Represents an individual value within an enum, with optional name override.
EnumModel<T>
ExplicitResponseStatus
ExternalDocumentation
FilterConfig
Configuration for filtering which parts of the spec to generate.
HttpSecurityScheme
IntegerModel
License
ListModel
Model
MutualTlsSecurityScheme
NameOverridesConfig
Configuration for overriding generated names.
NeverModel
NumberModel
OAuth2Flow
OAuth2Flows
OAuth2SecurityScheme
OneOfModel
OpenIdConnectSecurityScheme
Operation
PathParameter
PathParameterAlias
PathParameterObject
PrimitiveModel
Property
QueryParameter
QueryParameterAlias
QueryParameterObject
RangeResponseStatus
RequestBody
RequestBodyAlias
RequestBodyObject
RequestContent
RequestHeader
RequestHeaderAlias
RequestHeaderObject
Response
ResponseAlias
ResponseBody
ResponseHeader
ResponseHeaderAlias
ResponseHeaderObject
ResponseObject
ResponseStatus
SecurityRequirement
SecurityScheme
Server
ServerVariable
Represents a server variable for URL template substitution.
StringModel
Tag
Represents a tag that groups related operations in an API.
TonikConfig
Main configuration for Tonik code generation.
UriModel

Enums

ApiKeyLocation
ContentType
CookieParameterEncoding
Encoding styles supported for cookie parameters.
DeprecatedHandling
How to handle deprecated elements during code generation.
HeaderParameterEncoding
Encoding style supported for header parameters.
HttpMethod
PathParameterEncoding
Encoding styles supported for path parameters.
QueryParameterEncoding
Encoding styles supported for query parameters.
ResponseHeaderEncoding
Encoding style supported for response headers .
SchemaContentType
SecuritySchemeType

Extensions

StableModelKey on Model
Extension on Model providing stable key generation for sorting.
StableSortedDiscriminatedModels on Set<DiscriminatedModel>
Extension on Set<DiscriminatedModel> to provide stable sorted lists.
StableSortedModels on Set<Model>
Extension on Set<Model> to provide stable sorted lists.

Typedefs

DiscriminatedModel = ({String? discriminatorValue, Model model})