ApiKeySecurityScheme class

Inheritance

Constructors

ApiKeySecurityScheme({required SecuritySchemeType type, required ApiKeyLocation location, required String? description})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
location ApiKeyLocation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SecuritySchemeType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited