CookieParameterObject class

Inheritance

Constructors

CookieParameterObject({required String? name, required String rawName, required String? description, required bool isRequired, required bool isDeprecated, required bool explode, required Model model, required CookieParameterEncoding encoding, required Context context, String? nameOverride})

Properties

context Context
finalinherited
description String?
The description of the parameter. For aliases, this may override the referenced parameter's description.
getter/setter pairoverride-getter
encoding CookieParameterEncoding
getter/setter pair
explode bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDeprecated bool
getter/setter pair
isRequired bool
getter/setter pair
model Model
getter/setter pair
name String?
final
nameOverride String?
getter/setter pair
rawName String
The name used inside the HTTP request to identify the cookie.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({String? name, String? nameOverride}) CookieParameterObject
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited