NeverModel class

Inheritance

Constructors

NeverModel({required Context context})

Properties

context Context
finalinherited
encodingShape → EncodingShape
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEffectivelyNullable bool
Whether this model produces a nullable Dart type, including through typedef/alias chains.
no setterinherited
resolved Model
The terminal model after resolving through any AliasModel chains.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited