Property class

Constructors

Property({required String name, required Model model, required bool isRequired, required bool isNullable, required bool isDeprecated, bool isReadOnly = false, bool isWriteOnly = false, String? nameOverride, String? description})

Properties

description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDeprecated bool
getter/setter pair
isNullable bool
getter/setter pair
isReadOnly bool
getter/setter pair
isRequired bool
getter/setter pair
isWriteOnly bool
getter/setter pair
model Model
getter/setter pair
name String
final
nameOverride String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited