QueryParameter class sealed

Implementers

Properties

context Context
final
description String?
The description of the parameter. For aliases, this may override the referenced parameter's description.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({String? name, String? nameOverride}) QueryParameterObject
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited