ClassModel class
- Inheritance
- Mixed-in types
Constructors
Properties
- additionalProperties ↔ AdditionalProperties?
-
getter/setter pair
- context → Context
-
finalinherited
- description ↔ String?
-
getter/setter pair
- encodingShape → EncodingShape
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeprecated ↔ bool
-
getter/setter pair
- isEffectivelyNullable → bool
-
Whether this model produces a nullable Dart type, including through
typedef/alias chains.
no setterinherited
- isNullable ↔ bool
-
getter/setter pair
- isReadOnly ↔ bool
-
getter/setter pair
- isWriteOnly ↔ bool
-
getter/setter pair
- name → String?
-
final
- nameOverride ↔ String?
-
getter/setter pairoverride
-
properties
↔ List<
Property> -
getter/setter pair
- resolved → Model
-
The terminal model after resolving through any AliasModel chains.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited