DecimalModel class
- Inheritance
-
- Object
- Model
- PrimitiveModel
- DecimalModel
- Available extensions
Constructors
- DecimalModel({required Context context})
Properties
- context → Context
-
finalinherited
- encodingShape → EncodingShape
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stableKey → String
-
Available on Model, provided by the StableModelKey extension
Creates a stable string representation of a model for sorting purposes.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited