MultipartPropertyEncoding class
Encoding metadata for a single property in a multipart/form-data request.
- Annotations
-
- @immutable
Constructors
-
MultipartPropertyEncoding({ContentType? contentType, String? rawContentType, Map<
String, ResponseHeader> ? headers, MultipartEncodingStyle? style, bool? explode, bool? allowReserved}) -
const
Properties
- allowReserved → bool?
-
Whether reserved characters are allowed without encoding.
final
- contentType → ContentType?
-
Typed content type for this property's part.
final
- explode → bool?
-
Whether arrays/objects generate separate values.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
headers
→ Map<
String, ResponseHeader> ? -
Per-part headers, resolved from encoding header refs.
final
- isStyleBased → bool
-
Whether this encoding uses style-based serialization mode.
no setter
- rawContentType → String?
-
Raw content type string for this property's part (e.g. 'application/json').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → MultipartEncodingStyle?
-
Serialization style for this property.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override